-----------------------------------------------------------------------------------------
-- Start Activity
-----------------------------------------------------------------------------------------
-- Notice that or class is the same as in UI.lua. That's because we're running in the same activity
-- we just replaced UpdateActivity and StartActivity functions.
function MissionTutorial_09:StartActivity()
	-- In normal activity StartActivity is launched when activity starts. To keep our mission script comparible with
	-- ordinary activities we also put all init procedures in StartActivity, but in our case CC will never run this
	-- function because it already initialized activity when UI.lua was launched. So we just need to manually run 
	-- this function the first time our new UpdateActivity function starts. After initialization has been run we set 
	-- the flag that second part of activity is initialized.
	if self.IsInitialized == nil then
		self.IsInitialized = false
	end

	if self.IsInitialized then 
		return
	end

	self.IsInitialized = true	
	
	-- All comments are removed, I left only comments which describe the multiple faction thing
	print("START! -- MissionTutorial_09:StartActivity()!");
	
	self.DummyLZ = SceneMan.Scene:GetArea("DummyLZ");
	
	self.braindead = {};
	self.AssignedBrains = {};
	self.MOIDLimit = 200;
    
	self.PlayerGold = 0;

   	self.CPUTeam = Activity.TEAM_2;
	self.PlayerTeam = Activity.TEAM_1;
	self.RogueTeam = -1;

	self.DummySpawnTimer = Timer();
	self.CoalitionSpawnTimer = Timer();
	
	self.DummySpawnInterval = 16000;
	self.CoalitionSpawnInterval = 8000;
	
	for player = 0, self.PlayerCount - 1 do
		self.braindead[player] = false;
		local brain = CF_MakeBrain(self.PlayerTeam, CF_PlayerFaction, true)
		brain.Pos = Vector(150 + player * 30 , 550);
		brain.AIMode = Actor.AIMODE_SENTRY;
		MovableMan:AddActor(brain)
		SceneMan:SetScroll(brain.Pos, player);
		self:SetObservationTarget(brain.Pos, player);
		self:SwitchToActor(brain, player, self.PlayerTeam);
    end

    for actor in MovableMan.AddedActors do
		actor.AIMode = Actor.AIMODE_SENTRY;
    end
	
    self:SetTeamFunds(self.PlayerGold , self.PlayerTeam);
	
	self.DummySpawnTimer:Reset();
	self.CoalitionSpawnTimer:Reset();
end
-----------------------------------------------------------------------------------------
-- Pause Activity
-----------------------------------------------------------------------------------------
function MissionTutorial_09:PauseActivity(pause)
    print("PAUSE! -- MissionTutorial_09:PauseActivity()!");
end
-----------------------------------------------------------------------------------------
-- End Activity
-----------------------------------------------------------------------------------------
function MissionTutorial_09:EndActivity()
    print("END! -- MissionTutorial_09:EndActivity()!");
end
-----------------------------------------------------------------------------------------
-- Update Activity
-----------------------------------------------------------------------------------------
function MissionTutorial_09:UpdateActivity()
	-- START
	--	This is what differs two-part activity from an ordinary one. You have to manually init second part of the activity
	-- the first time then UpdateActivity functions works.
	-- Just check for intialization flags in update loop to avoid unnecessary function calls during all the mission
	if self.IsInitialized == nil then
		self.IsInitialized = false
	end
	
	if not self.IsInitialized then
		--Init mission if we're still not
		self:StartActivity()
	end	
	-- END

   	self:ClearObjectivePoints();

	self:PhaseNoFight();
	
	self:DoBrainSelection();
	
	self:YSortObjectivePoints();
end
-----------------------------------------------------------------------------------------
-- Brain selection and gameover conditions check
-----------------------------------------------------------------------------------------
function MissionTutorial_09:DoBrainSelection()
	if not (self.ActivityState == Activity.OVER) then
		for player = 0, self.PlayerCount - 1 do
			local team = self:GetTeamOfPlayer(player);
	
			local brain = self:GetPlayerBrain(player);
			if not brain or not MovableMan:IsActor(brain) then
				self:SetPlayerBrain(nil, player);
				local newBrain = MovableMan:GetUnassignedBrain(team);
				if newBrain and self.braindead[player] == false then
					self:SetPlayerBrain(newBrain, player);
					self:SwitchToActor(newBrain, player, team);
				else
					FrameMan:SetScreenText("Commander died!", player, 100, -1, false);
					self.braindead[player] = true;
					
					self.WinnerTeam = self:OtherTeam(team);
					ActivityMan:EndActivity();
				end
			else
				self:SetObservationTarget(brain.Pos, player)
			end -- 
		end --for
	end --if
end
-----------------------------------------------------------------------------------------
-- Spawn dummy dropship
-----------------------------------------------------------------------------------------
function MissionTutorial_09:SpawnDropship()
		local ship = CF_MakeDropship(self.CPUTeam, Vector(self.DummyLZ:GetRandomPoint().X, 0), CF_CPUFaction, false)
		local actor = nil;
		local weapon = nil;
		
		if ship ~= nil then
			for i = 0 , 1 do
					if math.random() > 0.05 then
						-- Get random unit with random weapons. 
						-- Team = self.CPUTeam. 
						-- Position = nil, means that actor won't be placed but returned as function result.
						-- Faction - CF_Factions[math.random(#CF_Factions)], choose random faction from list
						-- AIMODE - Actor.AIMODE_BRAINHUNT
						actor = CF_SpawnRandomInfantry(self.CPUTeam , nil , CF_CPUFaction , Actor.AIMODE_BRAINHUNT)
						-- Give new actor some special equipment
						actor:AddInventoryItem(CreateHDFirearm("Medium Digger"));
					else
						-- Spawn armor unit of selected faction. Arguments are the same as for CF_SpawnRandomInfantry
						actor[x] = CF_SpawnArmor(self.CPUTeam , nil , CF_CPUFaction , Actor.AIMODE_BRAINHUNT)
						break;
					end

				ship:AddInventoryItem(actor);
			end -- for

			MovableMan:AddActor(ship);
		end
end
-----------------------------------------------------------------------------------------
-- Phase "No fight"
-----------------------------------------------------------------------------------------
function MissionTutorial_09:SpawnClone()

	-- Spawn friendly unit
	actor = CF_SpawnRandomInfantry(self.PlayerTeam , nil , CF_PlayerFaction , Actor.AIMODE_BRAINHUNT)

	-- Reset it's AImode to more complex
	actor.AIMode = Actor.AIMODE_GOTO;
	actor:ClearAIWaypoints();
	actor:AddAISceneWaypoint(Vector(1800 , 550));
	actor.Pos = Vector( 10 , 550);
	MovableMan:AddActor(actor);
end
-----------------------------------------------------------------------------------------
-- Phase "No fight"
-----------------------------------------------------------------------------------------
function MissionTutorial_09:PhaseNoFight()
	if self.DummySpawnTimer:IsPastSimMS(self.DummySpawnInterval) and MovableMan:GetMOIDCount() <= self.MOIDLimit then
		self:SpawnDropship();
		self.DummySpawnTimer:Reset();
	end

	if self.CoalitionSpawnTimer:IsPastSimMS(self.CoalitionSpawnInterval) and MovableMan:GetMOIDCount() <= self.MOIDLimit then
		self:SpawnClone();
		self.CoalitionSpawnTimer:Reset();
	end
end
-----------------------------------------------------------------------------------------
-- That's all folks!
-----------------------------------------------------------------------------------------



































