-- This is where our activity starts. This scripts implements UI controls and then 
-- transfers controls to another script. The activity remains the same, we don't 
-- launch another one. This trick allows us to keep the team\player count and settings.
-- If we launch new activity, players will be set to 1 player vs CPU.
-----------------------------------------------------------------------------------------
-- Start Activity
-----------------------------------------------------------------------------------------
function MissionTutorial_09:StartActivity()
	self.ModuleName = "MissionTut_09.rte";

	self.ScriptPath = self.ModuleName.."/Scenes/Scripts/"
	self.LibPath = self.ModuleName.."/Libraries/"
	self.SceneToLaunch = SceneMan.Scene.PresetName;
	-- Script to launch when we finished selecting factions. This is where you need to write your mission script.
	-- It's a bit different from ordinary missions, so look at MissionTut_09.lua for details.
	self.ScriptToLaunch = "MissionTut_09.lua"; 
	
	-- Manually load needed scene. Be careful, LoadScene is case-sensitive.
	SceneMan:LoadScene("UI" , true)
	
	-- Load campaign framework library files. They contain all global functions and variables
	-- started with CF_
	-- This is a simple library from Tartarus and BlockWars which use the simple faction
	-- format. You can take libraries from Unmapped lands and get more function but you'll
	-- have to use more complex Unmapped Lands faction files
	dofile(self.LibPath.."CF_ConfigLibrary.lua");
	dofile(self.LibPath.."CF_MissionLibrary.lua");

	-- Initialize campaign framework. Load faction lists, init fariables etc.
	CF_InitFactions(self.ModuleName);
	
	-- This area prevents CC from using incompatible scenes
	self.Zone = SceneMan.Scene:GetArea("MissionTut_09_Area");
	
	self.Elements = {};
	
	self.Modes = {PLAYERSELECT = 0 , CPUSELECT = 1};
	self.CurrentMode = self.Modes.PLAYERSELECT;
	
	self.MidX = SceneMan.Scene.Width / 2;
	self.MidY = SceneMan.Scene.Height / 2;
	self.Mid = Vector(self.MidX , self.MidY);

	self.ControlsEnabled = true;
	self.ControlPressed = 0;
	
	print("LOAD:Fill slot elements");
	CF_InitFactions(self.ModuleName)
	
	for i = 1, #CF_Factions do
		self.Elements[i] = {};
		
		self.Elements[i]["Description"] = CF_FactionNames[CF_Factions[i]];
		self.Elements[i]["FactionName"] = CF_FactionNames[CF_Factions[i]];
		self.Elements[i]["FactionId"] = CF_Factions[i];
		self.Elements[i]["Preset"] = "FactionBanner";
	end
	
	print("LOAD:Init elements");
	self.Selection = 1;
	self.XTiles = 8; -- Plates per row
	
	if #CF_Factions < self.XTiles then
		self.XTiles = #CF_Factions
	end
	
	self.YTiles = math.floor(#CF_Factions / self.XTiles + 1)
	--print (self.YTiles)
	
	self.HelpText = "Use MOVE LEFT and MOVE RIGHT to chose faction, press FIRE to confirm selection\n";
	
	self.ModeTexts = {}
	self.ModeTexts[self.Modes.PLAYERSELECT] = "Choose player faction\n"
	self.ModeTexts[self.Modes.CPUSELECT] = "Choose CPU faction\n"
	
	self.ElementsPos = {};
	
	local xtile = 1
	local ytile = 1
	local tilesperrow = 0
	
	-- Init factions UI
	for i = 1 , #CF_Factions do
		if i <= #CF_Factions - #CF_Factions % self.XTiles then
			tilesperrow = self.XTiles
		else
			tilesperrow = #CF_Factions % self.XTiles
		end
		
		self.ElementsPos[i] = Vector((self.MidX) - ((tilesperrow * 58) / 2) + (xtile * 58) - (58 / 2), 
									 (self.MidY) - ((self.YTiles * 68) / 2) + (ytile * 68) - (68 / 2))
		
		xtile = xtile + 1
		if xtile > self.XTiles then
			xtile = 1
			ytile = ytile + 1
		end
		
		CF_SpawnRandomInfantry(-1 , self.ElementsPos[i] , self.Elements[i]["FactionId"] , Actor.AIMODE_SENTRY)
		-- CF_SpawnRandomInfantry(i % 2 , self.ElementsPos[i] , self.Elements[i]["FactionId"] , Actor.AIMODE_SENTRY)
	end
	
	self.Plates = {};
	
	--Make an invisible brain.
	self.brain = CreateActor("Brain Case");
	self.brain.Scale = 0;
	self.brain.Team = Activity.TEAM_1;
	self.brain.Pos = self.Mid;
	MovableMan:AddActor(self.brain);
	self:SetPlayerBrain(self.brain , Activity.TEAM_1);

	self:SwitchToActor(self.brain , 0 , -1);

   	for player = 1, self.PlayerCount - 1 do
		actor = CreateActor("Brain Case");
		actor.Scale = 0;
		actor.Team = Activity.TEAM_1;
		actor.Pos = self.Mid + Vector(0,player * 20);
		MovableMan:AddActor(actor);

		self:SwitchToActor(actor , player , -1);
		actor.Team = -1
	end

	self.FactionBack = nil;
	
	self.GenericTimer = Timer();
	self.GenericTimer:Reset();

	self:InitGui();
	
	self.UITimer = Timer();
	self.UITimer:Reset();
	
	self.IsInitialized = false	
end
-----------------------------------------------------------------------------------------
-- Pause Activity
-----------------------------------------------------------------------------------------
-- This function is called when mission is paused
function MissionTutorial_09:PauseActivity(pause)
end
-----------------------------------------------------------------------------------------
-- End Activity
-----------------------------------------------------------------------------------------
-- This function is called after mission has ended
function MissionTutorial_09:EndActivity()
end
-----------------------------------------------------------------------------------------
-- 
-----------------------------------------------------------------------------------------
function MissionTutorial_09:InitGui()
	self.Selection = 1;
	self:RedrawAllPlates();
	self.GenericTimer:Reset();
end
-----------------------------------------------------------------------------------------
-- Redraw load menu plate
-----------------------------------------------------------------------------------------
function MissionTutorial_09:RedrawPlate(platenum , isselected , ispressed)
	if MovableMan:IsParticle(self.Plates[platenum]) then
		MovableMan:RemoveParticle(self.Plates[platenum]);
		self.Plates[platenum] = nil;
	end

	local preset;

	if isselected then
		preset = self.Elements[platenum]["Preset"].."MouseOver";
	else
		preset = self.Elements[platenum]["Preset"].."Idle";
	end
	
	if ispressed then
		preset = self.Elements[platenum]["Preset"].."Pressed";
	end

	self.Plates[platenum] = CreateMOSRotating(preset , self.ModuleName);
	if isselected then
		self.Plates[platenum].SpriteAnimMode = 1;
	end
	
	self.Plates[platenum].Pos = self.ElementsPos[platenum];
	MovableMan:AddParticle(self.Plates[platenum]);	
end
-----------------------------------------------------------------------------------------
-- 
-----------------------------------------------------------------------------------------
function MissionTutorial_09:RedrawAllPlates()
	for i = 1, #self.Elements do
		self:RedrawPlate(i , false , false);
	end

	self:RedrawPlate(self.Selection , true , false);
end
-----------------------------------------------------------------------------------------
-- Update Activity
-----------------------------------------------------------------------------------------
function MissionTutorial_09:UpdateActivity()
	--Move the cursor.
	local cont = self.brain:GetController();

    for actor in MovableMan.Actors do
		actor.Vel = Vector(0 , 0)
	end

	--print(self:PlayersInTeamCount(Activity.TEAM_1))
	
   	self:ClearObjectivePoints();
	self:AddObjectivePoint(self.ModeTexts[self.CurrentMode]..self.Elements[self.Selection]["Description"], self.ElementsPos[self.Selection] + Vector(0,-35) , CF_PlayerTeam, GameActivity.ARROWDOWN);
	
   	for player = 0, self.PlayerCount - 1 do
		if player == 0 then
			FrameMan:SetScreenText("PLAYER ONE SELECTS!!!\n"..self.HelpText..self.ModeTexts[self.CurrentMode]..self.Elements[self.Selection]["Description"], player, 0, 1, false);
		else
			FrameMan:SetScreenText(string.format("PLAYER %d OBEYS!!!\n" , player + 1)..self.Elements[self.Selection]["Description"], player, 0, 1, false);
		end
	end
	
	-- Add delay to avoid triggering multiple button hits when player holds key for too long
	if self.GenericTimer:IsPastSimMS(350) then
		if self.ControlsEnabled then
			if cont:IsState(Controller.PRESS_LEFT) then
				self:RedrawPlate(self.Selection , false , false);
				self.Selection = self.Selection - 1;
				if self.Selection <= 0 then 
					self.Selection = #self.Elements;
				end
				self:RedrawPlate(self.Selection , true , false);
			end

			if cont:IsState(Controller.PRESS_RIGHT) then
				self:RedrawPlate(self.Selection , false , false);
				self.Selection = self.Selection + 1;
				if self.Selection > #self.Elements then 
					self.Selection = 1;
				end
				self:RedrawPlate(self.Selection , true , false);
			end

			--If fire has been pushed.
			if cont:IsState(Controller.WEAPON_FIRE) then
				self.ControlPressed = self.Selection;
				self.ControlsEnabled = false;
				self.UITimer:Reset();
				self:RedrawPlate(self.Selection , false , true);
				self.GenericTimer:Reset();
			end
		end
	end

	if self.ControlPressed > 0 then
		if self.UITimer:IsPastSimMS(350) then
			self:RedrawPlate(self.ControlPressed , true , false);

			if self.CurrentMode == self.Modes.CPUSELECT then
				CF_CPUFaction = self.Elements[self.Selection]["FactionId"]
				
				print ("Player = "..CF_PlayerFaction)
				print ("CPU = "..CF_CPUFaction)
				
				-- Reset initializetion flag, since we're preparing to launch second part of activity
				-- which is not initialized yet.
				self.IsInitialized = false;
				
				for player = 0, self.PlayerCount - 1 do
					FrameMan:ClearScreenText(player);
				end
				
				-- This is where the magic happens. We replace currently running UpdateActivity function with script we need to launch
				
				dofile(self.ScriptPath..self.ScriptToLaunch)
				-- Then load needed scene
				SceneMan:LoadScene(self.SceneToLaunch , true)
				-- and immediatly return from current function. Right after this the new function will control the activity.
				return;
			end
			
			if self.CurrentMode == self.Modes.PLAYERSELECT then
				--for actor in MovableMan.Actors do
				--	actor:FlashWhite(500)
				--end

				CF_PlayerFaction = self.Elements[self.Selection]["FactionId"]
				self.CurrentMode = self.Modes.CPUSELECT
			end--]]--
			
			self.ControlsEnabled = true;
			self.ControlPressed = 0;				
		end
	end
end
-----------------------------------------------------------------------------------------
-- Thats all folks!!!
-----------------------------------------------------------------------------------------